use Config;
use Data::Dumper;
use ExtUtils::MakeMaker;
use File::Basename qw(basename);
# See lib/ExtUtils/MakeMaker.pm for details of how to influence
# the contents of the Makefile that is written.
WriteMakefile
  (
   NAME         => 'Wlanctl',
   VERSION_FROM => 'Wlanctl.pm', # finds $VERSION
   AUTHOR       => 'Bryan Jurish <moocow@ling.uni-potsdam.de>',
   ABSTRACT     => 'Perl WLAN utilities',

   EXE_FILES    => ['wlanctl.perl', 'gtkwlan.perl', 'dhclient_stop.sh'],
   CONFIGURE    => \&wlanctl_configure, ##-- return a hashref of more variables
   PM_FILTER    => '\$(PERL) wlanctl_pmfilter.perl', ##-- UNIX filter for PM files
   PM           => {
		    'Wlanctl.pm'=>'$(INST_LIBDIR)/Wlanctl.pm',
		    'Wlanctl/GUI.pm'=>'$(INST_LIBDIR)/Wlanctl/GUI.pm',
		    'Wlanctl/Config.pm'=>'$(INST_LIBDIR)/Wlanctl/Config.pm',
		    (map {
		      ($_=>('$(INST_LIBDIR)/Wlanctl/GUI/pixmaps/'.basename($_)))
		    } glob("Wlanctl/GUI/pixmaps/*.xpm")),
		   },

   PREREQ_PM    => {
		    Linux::Iwtools=>0.01,
		    Gtk => 0.7009,
		    Data::Dumper=>undef,
		    Storable=>undef,
		    File::Basename=>undef,
		   },
  );

#---------------------------------------------------------------
# Extensions
#---------------------------------------------------------------

#sub MY::install {
#  # need to install pixmaps
#  my $inherited = shift->SUPER::install(@_);
#  $inherited =~ s/^(install\s*::\s*.*)$/$1 pixmaps_install/m;
#  $inherited .=
#    ("pixmaps_install:\n",
#     "\t\$(PERLRUN) -MExtUtils::Install ???");
#}

sub MY::postamble {
  # how to format the README file
  ("README.txt : README.pod\n"
   ."\tpod2text README.pod README.txt\n"
  );
}

sub MY::dist_core {
  package MY;
  my $inherited = shift->SUPER::dist_core(@_);
  $inherited =~
    # ... distribution requires current README file
    s/^dist\s*:/dist\ : README.txt/m;
  $inherited;
}

##---------------------------------------------------------------
## Library scanning: ignore some stuff (no!)
##  - should work according to ExtUtils::MakeMaker, but it don't
##---------------------------------------------------------------
sub my_libscan {
  my $file = shift;
  return $file !~ /^README/;
}


##---------------------------------------------------------------
## Configuration: Guts
##---------------------------------------------------------------

## cprompt($key,$prompt);
sub cprompt {
  my ($key,$prompt,$default) = @_;
  $default = $config{$key} if (defined($config{$key}));
  $config{$key} = prompt($prompt,$default) if (!defined($config{$key}));
}

## progprompt($key);
## progprompt($key,$progname);
sub progprompt {
  my ($key,$prog) = @_;
  $prog = $key if (!$prog);

  ##-- search for prog
  my $default = '';
  foreach my $top (qw(/ /usr/ /usr/local/)) {
    foreach my $bin (qw(bin/ sbin/)) {
      if (-x "${top}${bin}${prog}") {
	$default = "${top}${bin}${prog}";
	last;
      }
    }
    last if ($default);
  }
  $default = $prog if (!$default);

  cprompt($key,"Where is your \`$prog\' program",$default);
}

##---------------------------------------------------------------
## Configuration: Top-level
##---------------------------------------------------------------
our %config;
sub wlanctl_configure {
  ##-- read in config.cache if it exists
  if (-f "config.cache") {
    do "config.cache";
    die ("$0: error reading 'config.cache': $@") if ($@);
    %config = %$config;
  }

  ##-- program variables
  foreach $prog (qw(iwconfig iwlist sudo),
		 qw(modprobe cardctl),
		 qw(ifconfig route dhclient))
    {
      progprompt($prog);
    }
  $config{dhclient_stop} = "$Config{installscript}/dhclient_stop.sh";

  ##-- Default configuration dir
  my $dconfigdir = -d "/etc/default" ? "/etc/default" : "/etc";
  cprompt('default_config_dir',
	  "Where are system-wide configuration files stored",
	  $dconfigdir);

  ##-- xpm directory
  #cprompt('xpm_dir',
	# "Where should the GUI pixmaps be installed",
	# '/usr/local/share/Wlanctl/pixmaps');
  #$config{xpm_dir} = "$Config{installlibdir}/Wlanctl/GUI/pixmaps";

  ##-- save config.cache
  open(CACHE,">config.cache") or die("$0: open failed for config.cache: $!");
  print CACHE Data::Dumper->Dump([\%config],['$config']);
  close(CACHE);

  ##-- show configuration
  print Data::Dumper->Dump([\%config],['$Configuration']);

  ##-- return
  return {};
}
