#!/usr/bin/perl -w

##----------------------------------------------------------------------
## File: wlanctl.perl
## Author: Bryan Jurish <moocow@ling.uni-potsdam.de>
## Description:
##   + command-line control interface for Wlanctl.pm module
##----------------------------------------------------------------------

use lib qw(.);
use Gtk qw(-init);
use Wlanctl qw(:verbose);
use Wlanctl::GUI;
use Getopt::Long;
use Pod::Usage;
use File::Basename qw(basename);

##----------------------------------------------------------------------
## Globals
##----------------------------------------------------------------------
our $VERSION = $Wlanctl::VERSION;
our $PROG    = basename($0, '.perl');

##----------------------------------------------------------------------
## Defaults
##----------------------------------------------------------------------
our %config =
  (
   verbose=>'default',
  );
our $network_name = undef;

##----------------------------------------------------------------------
## Globals
##----------------------------------------------------------------------
GetOptions(##-- general options
	   'help|h!' => \$help,
	   'man!'    => \$man,
	   'version!' => \$version,

	   ##-- configuration options
	   'config|c=s'  => \$alt_config_file,
	   'netname|net|name|n=s' => \$network_name,
	  );

pod2usage({
	   -exitval=>0,
	   -verbose=>0
	  }) if ($help);
pod2usage({
	   -exitval=>0,
	   -verbose=>1
	  }) if ($man);

if ($version) {
  print "$PROG version $VERSION by Bryan Jurish\n";
  exit 0;
}

##======================================================================
## MAIN
##======================================================================

##-- create object
$wg = Wlanctl::GUI->new(%config);

##-- read config, state
$wg->readDefaultConfig;
$wg->readConfigFile($alt_config_file) if ($alt_config_file);
$wg->readConfigFile("$ENV{HOME}/.gtkwlanrc") if (-r "$ENV{HOME}/.gtkwlanrc");
$wg->loadState;
$wg->_index();

$wg->{default_network} = $wg->{networks_byname}{$network_name}
  if ($network_name);

##-- parse user's .gtkrc
if (-r "$ENV{HOME}/.gtkrc") { Gtk::Rc->parse("$ENV{HOME}/.gtkrc"); }
#if (-r "$ENV{HOME}/.gtkwlanrc") { Gtk::Rc->parse("$ENV{HOME}/.gtkwlanrc"); }

##-- GUI
$wg->initialize();
$wg->update();
if ($wg->{status}{isup}) { $wg->_refresh; }
$wg->{gui}{main}->show_all;
Gtk->main;
exit 0;

##======================================================================
## Pods
##======================================================================
=pod

=head1 NAME

wlanctl.perl - command-line control for Wlanctl module

=head1 SYNOPSIS

 wlanctl.perl [OPTIONS] ACTION(s)

 General Options:
   -help
   -version
   -nobanner
   -verbose LEVEL

 Configuration Options:
   -netname NETWORK

=cut

###############################################################
# Arguments
###############################################################
=pod

=head1 ARGUMENTS

ACTION is one of the following:

=over 4

=item on

Enable the WLAN device.

=item off

Disable the WLAN device.

=item up

Initiate a WLAN connection to the default network.

=item down

Terminate the most recently initiated WLAN connection.

=item list

List known networks.

=item scan

Scan for available networks.

=item status

Show WLAN connection status. TODO

=back

=cut

###############################################################
# Options
###############################################################
=pod

=head1 OPTIONS

=cut

###############################################################
# General Options
###############################################################
=pod

=head2 General Options

=over 4

=item -help

Display a brief help message and exit.

=item -version

Display version information and exit.

=item -verbose LEVEL

Set verbosity level to LEVEL.  Default=1, Max=5.

=item -nobanner

Suppress version banner.

=back

=cut


###############################################################
# Socket Options
###############################################################
=pod

=head2 Configuration Options

Not yet written.

=cut

###############################################################
# Bugs and Limitations
###############################################################
=pod

=head1 BUGS AND LIMITATIONS

Many.

=cut

###############################################################
# Footer
###############################################################
=pod

=head1 ACKNOWLEDGEMENTS

perl by Larry Wall.

=head1 AUTHOR

Bryan Jurish E<lt>moocow@ling.uni-potsdam.deE<gt>

=head1 SEE ALSO

perl(1),
Wlanctl(3pm).

=cut
